@@ -1,9 +1,14 @@
+use 5.006;
+use strict;
+use warnings;
+
 package Object::AUTHORITY;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.100';
+our $VERSION   = '0.102';
 
 use Role::Commons ();
+use Role::Commons::Authority ();
 
 sub import
 {
@@ -16,5 +21,7 @@ sub import
 	Role::Commons::->import('Authority', -into => $_) for @packages;
 }
 
+*AUTHORITY = Role::Commons::Authority::->can('AUTHORITY');
+
 1;
 
